/* This file is part of the KDE libraries
    Copyright (C) 2005, 2006 KJSEmbed Authors
    See included AUTHORS file.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/
#include <QDebug>

#include "object_binding.h"
#include "variant_binding.h"
#include <kjs/object.h>

#include "bind_qtimer.h"

using namespace KJSEmbed;

namespace TimerNS {
}

NO_ENUMS( Timer )
NO_METHODS( Timer )
NO_STATICS( Timer )

KJSO_SIMPLE_BINDING_CTOR( Timer, QTimer, QObjectBinding )
KJSO_QOBJECT_BIND( Timer, QTimer )

KJSO_START_CTOR( Timer, QTimer, 0 )
    QObject *parent = KJSEmbed::extractObject<QObject>( exec, args, 0 );
    QTimer *a = new QTimer( parent );
    return new KJSEmbed::QObjectBinding( exec, a );
KJSO_END_CTOR


//kate: indent-spaces on; indent-width 4; replace-tabs on; indent-mode cstyle;
